parserFwk.pyparsing.ParseException

Package parserFwk :: Module pyparsing :: Class ParseException |
[frames | no frames]

## Class ParseException

         Exception --+
                     |
    ParseBaseException --+
                         |
                        ParseException

exception thrown when parse expressions don't match class; supported attributes by name are:

- lineno - returns the line number of the exception text
- col - returns the column number of the exception text
- line - returns the line containing the exception text

Method Summary
Inherited from `ParseBaseException`: `__init__`, `__getattr__`, `__repr__`, `__str__`, `markInputline` Inherited from `Exception`: `__getitem__`

Class Variable Summary
Inherited from `ParseBaseException`: `__slots__`

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net